==> ssp-center-api-0.8.42-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotStableChargeDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

public class SlotStableChargeDto extends BaseDto {

    private static final long serialVersionUID = 1468732344070695793L;

    private Long      appId;
    private Long      slotId;
    private Integer   chargeType;
    private Integer   price;
    private Integer   chargeFloat;
    private Integer   mediaSplitRatio;
    private Integer   afterFloat;

    /** 托管开启状态:0-关闭,1-开启 **/
    private Integer isHosting;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Integer getPrice() {
        return price;
    }

    public void setPrice(Integer price) {
        this.price = price;
    }

    public Integer getChargeFloat() {
        return chargeFloat;
    }

    public void setChargeFloat(Integer chargeFloat) {
        this.chargeFloat = chargeFloat;
    }

    public Integer getMediaSplitRatio() {
        return mediaSplitRatio;
    }

    public void setMediaSplitRatio(Integer mediaSplitRatio) {
        this.mediaSplitRatio = mediaSplitRatio;
    }

    public Integer getAfterFloat() {
        return afterFloat;
    }

    public void setAfterFloat(Integer afterFloat) {
        this.afterFloat = afterFloat;
    }

    public Integer getIsHosting() {
        return isHosting;
    }

    public void setIsHosting(Integer isHosting) {
        this.isHosting = isHosting;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> ssp-center-api-1.2.88-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotStableChargeDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.math.BigDecimal;

public class SlotStableChargeDto extends BaseDto {

    private static final long serialVersionUID = -3401482915721646234L;

    public static final Integer HOSTING_TURN_ON = 1;
    public static final Integer HOSTING_TURN_OFF = 0;

    private Long      appId;
    private Long      slotId;
    private Integer   chargeType;
    private Integer   price;
    private Integer   chargeFloat;
    private Integer   mediaSplitRatio;
    private Integer   afterFloat;

    /** 托管开启状态:0-关闭,1-开启 **/
    private Integer isHosting;

    /**
     * 媒体预期UV收益最小值
     */
    private BigDecimal minExpectArpu;

    /**
     * 媒体预期UV收益最大值
     */
    private BigDecimal maxExpectArpu;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Integer getPrice() {
        return price;
    }

    public void setPrice(Integer price) {
        this.price = price;
    }

    public Integer getChargeFloat() {
        return chargeFloat;
    }

    public void setChargeFloat(Integer chargeFloat) {
        this.chargeFloat = chargeFloat;
    }

    public Integer getMediaSplitRatio() {
        return mediaSplitRatio;
    }

    public void setMediaSplitRatio(Integer mediaSplitRatio) {
        this.mediaSplitRatio = mediaSplitRatio;
    }

    public Integer getAfterFloat() {
        return afterFloat;
    }

    public void setAfterFloat(Integer afterFloat) {
        this.afterFloat = afterFloat;
    }

    public Integer getIsHosting() {
        return isHosting;
    }

    public void setIsHosting(Integer isHosting) {
        this.isHosting = isHosting;
    }

    public BigDecimal getMinExpectArpu() {
        return minExpectArpu;
    }

    public void setMinExpectArpu(BigDecimal minExpectArpu) {
        this.minExpectArpu = minExpectArpu;
    }

    public BigDecimal getMaxExpectArpu() {
        return maxExpectArpu;
    }

    public void setMaxExpectArpu(BigDecimal maxExpectArpu) {
        this.maxExpectArpu = maxExpectArpu;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
